#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.artsoft.org/rocksndiamonds/
# source           :
# http://www.artsoft.org/RELEASES/unix/rocksndiamonds/rocksndiamonds-3.2.6.0.tar.gz

# Package name
NAME="rocksndiamonds"
# Package version
VERSION="3.2.6.0"
# Source code URL
SOURCE="http://www.artsoft.org/RELEASES/unix/rocksndiamonds/rocksndiamonds-$VERSION.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="CHANGES COPYING CREDITS ChangeLog HARDWARE README TODO $NAME-$VERSION.lsm"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="54.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: rocksndiamonds is an arcade style game
$NAME:
$NAME: Rocks'n'Diamonds is an arcade style game in the tradition of 
$NAME: "Boulder Dash" (C 64), "Emerald Mine" (Amiga),
$NAME: "Supaplex" (Amiga/PC) and "Sokoban" (PC) 
$NAME: 
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if icons are present. If it's not, download it
if [ -f icons.tar.gz ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/icons.tar.gz
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz
tar xvzf icons.tar.gz

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Rocks'n'Diamonds
Exec=rocksndiamonds
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
Icon=rocksndiamonds
EOF

# Create a launch script
mkdir -p $PKG/usr/bin
cat > $PKG/usr/bin/$NAME <<EOF
#!/bin/sh
cd /usr/share/$NAME
./$NAME "\$@"
EOF
chmod a+x $PKG/usr/bin/$NAME

# No configure, just make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
sed -i -e 's/-O3//' src/Makefile
sed -i -e 's/-Wall/-Wall -O2 -march=i486 -mtune=i686/' src/Makefile
make

# Install on temporary directory (no make install rule)
mkdir -p $PKG/usr/share/$NAME
cp -a $NAME docs graphics levels music scores sounds $PKG/usr/share/$NAME

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy icons to the right place
ICONSIZES="64 48 32 24 16"
for i in $ICONSIZES; do
	mkdir -p $PKG/usr/share/icons/hicolor/$i\x$i/apps;
	mv $CWD/$NAME-$i.png $PKG/usr/share/icons/hicolor/$i\x$i/apps/$NAME.png;
done;

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION
mkdir -p $PKG/usr/man/man1
cp -a $NAME.1 $PKG/usr/man/man1

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Fix some permission
chmod 777 $PKG/usr/share/$NAME/scores

# Make the package
/sbin/makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
